### 0.2.0 (2014-08-09)

- major improvements to both cli and api
- tons of bug fixes
- additional features and options
- cleaned up storage of metadata and service information

### 0.1.1 (2014-03-20)

- small additions
- bug fixes

### 0.1.0 (2014-03-16)

- basic proof-of-concept
